Channel subscription management.
Tracks which channels the client is subscribed to and builds the
SystemOp::Subscribe / SystemOp::Unsubscribe messages.
Channel subscription management.
Tracks which channels the client is subscribed to and builds the
SystemOp::Subscribe / SystemOp::Unsubscribe messages.